<?php
namespace App\Controller;

use App\Entity\Place;
use App\Entity\User;
use App\Repository\TagRepository;
use App\Repository\UserRepository;
use App\Repository\PlaceRepository;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Doctrine\ORM\EntityManagerInterface;

 
class StaticPages extends AbstractController
{
    /**
     * @Route("/", name="home")
     */
    public function home(EntityManagerInterface $entityManager): Response
    {
        $titre = 'Bienvenue';

        $placeRepository = $entityManager->getRepository(Place::class);
        
        $placeCount = $placeRepository->createQueryBuilder('p')
            ->select('COUNT(p.id)')
            ->getQuery()
            ->getSingleScalarResult(); 

        $viewsCount = $placeRepository->createQueryBuilder('p')
            ->select('SUM(p.views)')
            ->getQuery()
            ->getSingleScalarResult();

        $orderedCount = $placeRepository->createQueryBuilder('p')
            ->select('SUM(p.ordered)')
            ->getQuery()
            ->getSingleScalarResult();
        
        $userRepository = $entityManager->getRepository(User::class);

        $userCount = $userRepository->createQueryBuilder('u')
            ->select('COUNT(u.id)')
            ->getQuery()
            ->getSingleScalarResult();
    
            
        $infoArray = [];

        array_push($infoArray, $placeCount, $viewsCount, $orderedCount, $userCount);
 
        return $this->render('home.html.twig', [
            'titre' => $titre,
            'info' => $infoArray
        ]);
    }

    /**
     * @Route("/admin", name="admin")
     */
    public function adminPanel(PlaceRepository $placeRepository, TagRepository $tagRepository, UserRepository $userRepository): Response
    {
        if (!$this->isGranted('ROLE_ADMIN')) {
            throw new AccessDeniedException('You must be logged in to access this page.');
        }

        $places = $placeRepository->findAll();
        $tags = $tagRepository->findAll();
        $users = $userRepository->findAll();
    
        return $this->render('admin.html.twig', [
            'places' => $places,
            'tags' => $tags,
            'users' => $users
        ]);
    }

     /**
     * @Route("/apropos", name="apropos")
     */
    public function apropos(): Response
    {
        $titre = 'À propos';

        return $this->render('apropos.html.twig', [
            'titre' => $titre
        ]);
    }
}