<?php

namespace App\Controller;

use App\Entity\Tag;
use App\Form\TagType;
use App\Repository\TagRepository;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Annotation\Route;
use Symfony\Component\Security\Core\Exception\AccessDeniedException;
use Symfony\Component\Routing\Generator\UrlGeneratorInterface;

#[Route('/tag')]
class TagController extends AbstractController
{
    #[Route('/', name: 'app_tag_index', methods: ['GET'])]
    public function index(TagRepository $tagRepository): Response
    {
        return $this->render('tag/index.html.twig', [
            'tags' => $tagRepository->findAll(),
        ]);
    }

    #[Route('/new', name: 'app_tag_new', methods: ['GET', 'POST'])]
    public function new(Request $request, TagRepository $tagRepository): Response
    {
        $this->denyAccessUnlessGranted('ROLE_ADMIN');

        $tag = new Tag();
        $form = $this->createForm(TagType::class, $tag);
        $form->handleRequest($request);

        if ($form->isSubmitted() && $form->isValid()) {
            $file = $request->files->get('tag')['svg'];
            $uploadsDirectory = $this->getParameter('uploads_directory');

            $fileName = md5(uniqid()) . '.' . $file->guessExtension();

            $file->move(
                $uploadsDirectory,
                $fileName
            );

            $tag->setSvg('/../uploads/' . $fileName);

            $tagRepository->save($tag, true);

            return $this->redirectToRoute('app_place_admin', [], Response::HTTP_SEE_OTHER);
        }

        return $this->renderForm('tag/new.html.twig', [
            'tag' => $tag,
            'form' => $form,
        ]);
    }

    // #[Route('/{id}', name: 'app_tag_show', methods: ['GET'])]
    // public function show(Tag $tag): Response
    // {
    //     return $this->render('tag/show.html.twig', [
    //         'tag' => $tag,
    //     ]);
    // }

    // #[Route('/{id}/edit', name: 'app_tag_edit', methods: ['GET', 'POST'])]
    // public function edit(Request $request, Tag $tag, TagRepository $tagRepository): Response
    // {
    //     $this->denyAccessUnlessGranted('ROLE_ADMIN');

    //     $form = $this->createForm(TagType::class, $tag);
    //     $form->handleRequest($request);

    //     if ($form->isSubmitted() && $form->isValid()) {
    //         $tagRepository->save($tag, true);

    //         return $this->redirectToRoute('app_place_admin', [], Response::HTTP_SEE_OTHER);
    //     }

    //     return $this->renderForm('tag/edit.html.twig', [
    //         'tag' => $tag,
    //         'form' => $form,
    //     ]);
    // }

    #[Route('/{id}', name: 'app_tag_delete', methods: ['POST'])]
    public function delete(Request $request, Tag $tag, TagRepository $tagRepository): Response
    {
        if ($this->isCsrfTokenValid('delete'.$tag->getId(), $request->request->get('_token'))) {
            $tagRepository->remove($tag, true);
        }

        return $this->redirectToRoute('app_place_admin', [], Response::HTTP_SEE_OTHER);
    }
}
