<?php

namespace App\Entity;

use App\Repository\PlaceRepository;
use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\Common\Collections\Collection;
use Doctrine\DBAL\Types\Types;
use Doctrine\ORM\Mapping as ORM;
use Symfony\Component\Form\DataTransformerInterface;
use Symfony\Component\HttpFoundation\File\File;

#[ORM\Entity(repositoryClass: PlaceRepository::class)]
class Place
{
    #[ORM\Id]
    #[ORM\GeneratedValue]
    #[ORM\Column]
    private ?int $id = null;

    #[ORM\Column(type: Types::TEXT)]
    private ?string $text = null;

    #[ORM\Column(type: Types::SMALLINT)]
    private ?int $price = null;

    #[ORM\Column(type: Types::TEXT)]
    private ?string $img = null;

    #[ORM\ManyToOne(inversedBy: 'places')]
    private ?Country $fk_country = null;

    #[ORM\Column(length: 255)]
    private ?string $name = null;

    #[ORM\ManyToMany(targetEntity: Tag::class, mappedBy: 'fk_place')]
    private Collection $tags;

    #[ORM\ManyToMany(targetEntity: User::class, inversedBy: 'places')]
    private Collection $fk_user;

    #[ORM\Column(nullable: true)]
    private ?int $ordered = null;

    #[ORM\Column]
    private ?int $views = null;

    public function __construct()
    {
        $this->tags = new ArrayCollection();
        $this->fk_user = new ArrayCollection();
    }

    public function __toString()
    {
        return $this->name;
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getText(): ?string
    {
        return $this->text;
    }

    public function setText(string $text): self
    {
        $this->text = $text;

        return $this;
    }

    public function getPrice(): ?int
    {
        return $this->price;
    }

    public function setPrice(int $price): self
    {
        $this->price = $price;

        return $this;
    }

    public function getImg(): ?string
    {
        return $this->img;
    }

    public function setImg(string $img): self
    {
        $this->img = $img;

        return $this;
    }

    public function getFkCountry(): ?Country
    {
        return $this->fk_country;
    }

    public function setFkCountry(?Country $fk_country): self
    {
        $this->fk_country = $fk_country;

        return $this;
    }

    public function getName(): ?string
    {
        return $this->name;
    }

    public function setName(string $name): self
    {
        $this->name = $name;

        return $this;
    }

    /**
     * @return Collection<int, Tag>
     */
    public function getTags(): Collection
    {
        return $this->tags;
    }

    public function addTag(Tag $tag): self
    {
        if (!$this->tags->contains($tag)) {
            $this->tags->add($tag);
            $tag->addFkPlace($this);
        }

        return $this;
    }

    public function removeTag(Tag $tag): self
    {
        if ($this->tags->removeElement($tag)) {
            $tag->removeFkPlace($this);
        }

        return $this;
    }

    /**
     * @return Collection<int, User>
     */
    public function getFkUser(): Collection
    {
        return $this->fk_user;
    }

    public function addFkUser(User $fkUser): self
    {
        if (!$this->fk_user->contains($fkUser)) {
            $this->fk_user->add($fkUser);
        }

        return $this;
    }

    public function removeFkUser(User $fkUser): self
    {
        $this->fk_user->removeElement($fkUser);

        return $this;
    }

    public function getOrdered(): ?int
    {
        return $this->ordered;
    }

    public function setOrdered(?int $ordered): self
    {
        $this->ordered = $ordered;

        return $this;
    }

    public function getViews(): ?int
    {
        return $this->views;
    }

    public function setViews(int $views): self
    {
        $this->views = $views;

        return $this;
    }
}
